@@ -94,6 +94,15 @@ static OidInfo oid_info[] = {
 	{ 0, "2.5.4.65", "pseudonym", N_("Pseudonym"),
 		EGG_OID_PRINTABLE | EGG_OID_IS_CHOICE },
 
+	{ 0, "1.2.643.100.1", "OGRN", N_("OGRN"),
+		EGG_OID_PRINTABLE },
+	{ 0, "1.2.643.100.3", "SNILS", N_("SNILS"),
+		EGG_OID_PRINTABLE },
+	{ 0, "1.2.643.100.5", "OGRNIP", N_("OGRNIP"),
+		EGG_OID_PRINTABLE },
+	{ 0, "1.2.643.3.131.1.1", "INN", N_("INN"),
+		EGG_OID_PRINTABLE },
+
 	{ 0, "1.2.840.113549.1.1.1", "rsaEncryption", N_("RSA"), 0 },
 	{ 0, "1.2.840.113549.1.1.2", "md2WithRSAEncryption", N_("MD2 with RSA"), 0 },
 	{ 0, "1.2.840.113549.1.1.4", "md5WithRSAEncryption", N_("MD5 with RSA"), 0 },
@@ -109,6 +118,13 @@ static OidInfo oid_info[] = {
 	{ 0, "1.2.840.10045.4.3.3", "sha384WithECDSA", N_("SHA384 with ECDSA"), 0 },
 	{ 0, "1.2.840.10045.4.3.4", "sha512WithECDSA", N_("SHA512 with ECDSA"), 0 },
 
+	{ 0, "1.2.643.2.2.3", "gostR3411-94-with-gostR3410-2001", N_("GOST R 34.11-94 with GOST R 34.10-2001"), 0 },
+	{ 0, "1.2.643.2.2.19", "gostr3410-2001", N_("GOST R 34.10-2001"), 0 },
+	{ 0, "1.2.643.7.1.1.1.1", "gost-3410-2012-256", N_("GOST R 34.10-2012 256-bit curve"), 0 },
+	{ 0, "1.2.643.7.1.1.1.2", "gost-3410-2012-512", N_("GOST R 34.10-2012 512-bit curve"), 0 },
+	{ 0, "1.2.643.7.1.1.3.2", "signwithdigest-gost-3410-2012-256", N_("GOST R 34.11-2012/256 with GOST R 34.10-2012 256-bit curve"), 0 },
+	{ 0, "1.2.643.7.1.1.3.3", "signwithdigest-gost-3410-2012-512", N_("GOST R 34.11-2012/512 with GOST R 34.10-2012 512-bit curve"), 0 },
+
 	/* Extended Key Usages */
 	{ 0, "1.3.6.1.5.5.7.3.1", NULL, N_("Server Authentication"), 0 },
 	{ 0, "1.3.6.1.5.5.7.3.2", NULL, N_("Client Authentication"), 0 },
